==> open-xchange-dav_7.10.3.orig.tar.bz2: open-xchange-dav-7.10.3/com.openexchange.dav/src/com/openexchange/dav/attachments/AttachmentResource.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.dav.attachments;

import java.io.InputStream;
import java.util.Date;
import com.openexchange.dav.AttachmentUtils;
import com.openexchange.dav.DAVFactory;
import com.openexchange.dav.resources.DAVResource;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.attach.AttachmentBase;
import com.openexchange.groupware.attach.AttachmentMetadata;
import com.openexchange.groupware.attach.Attachments;
import com.openexchange.webdav.protocol.WebdavPath;
import com.openexchange.webdav.protocol.WebdavProtocolException;

/**
 * {@link AttachmentResource}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.8.1
 */
public class AttachmentResource extends DAVResource {

    private final AttachmentMetadata attachment;

    /**
     * Initializes a new {@link AttachmentResource}.
     *
     * @param factory The factory
     * @param attachment The attachment
     * @param url The WebDAV path of the resource
     */
    public AttachmentResource(DAVFactory factory, AttachmentMetadata attachment, WebdavPath url) {
        super(factory, url);
        this.attachment = attachment;
    }

    @Override
    public String getDisplayName() throws WebdavProtocolException {
        return attachment.getFilename();
    }

    @Override
    public String getETag() throws WebdavProtocolException {
        if (false == exists() || null == attachment || null == attachment.getCreationDate()) {
            return "";
        }
        return "http://www.open-xchange.com/etags/" + attachment.getId() + "-" + attachment.getCreationDate().getTime();
    }

    @Override
    public Date getLastModified() throws WebdavProtocolException {
        return new Date(0);
    }

    @Override
    public Long getLength() throws WebdavProtocolException {
        return Long.valueOf(attachment.getFilesize());
    }

    @Override
    public String getContentType() throws WebdavProtocolException {
        return attachment.getFileMIMEType();
    }

    @Override
    public Date getCreationDate() throws WebdavProtocolException {
        return attachment.getCreationDate();
    }

    @Override
    public boolean hasBody() throws WebdavProtocolException {
        return true;
    }

    @Override
    public InputStream getBody() throws WebdavProtocolException {
        AttachmentBase attachments = Attachments.getInstance();
        try {
            return attachments.getAttachedFile(factory.getSession(), attachment.getFolderId(), attachment.getAttachedId(),
                attachment.getModuleId(), attachment.getId(), factory.getContext(), factory.getUser(), factory.getUserConfiguration());
        } catch (OXException e) {
            throw AttachmentUtils.protocolException(e, getUrl());
        }
    }

}

==> open-xchange-dav_7.10.5.orig.tar.bz2: open-xchange-dav-7.10.5/com.openexchange.dav/src/com/openexchange/dav/attachments/AttachmentResource.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.dav.attachments;

import java.io.InputStream;
import java.util.Date;
import com.openexchange.dav.AttachmentUtils;
import com.openexchange.dav.DAVFactory;
import com.openexchange.dav.resources.DAVResource;
import com.openexchange.exception.OXException;
import com.openexchange.groupware.attach.AttachmentBase;
import com.openexchange.groupware.attach.AttachmentMetadata;
import com.openexchange.groupware.attach.Attachments;
import com.openexchange.webdav.protocol.WebdavPath;
import com.openexchange.webdav.protocol.WebdavProtocolException;

/**
 * {@link AttachmentResource}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.8.1
 */
public class AttachmentResource extends DAVResource {

    private final AttachmentMetadata attachment;

    /**
     * Initializes a new {@link AttachmentResource}.
     *
     * @param factory The factory
     * @param attachment The attachment
     * @param url The WebDAV path of the resource
     */
    public AttachmentResource(DAVFactory factory, AttachmentMetadata attachment, WebdavPath url) {
        super(factory, url);
        this.attachment = attachment;
    }

    @Override
    public String getDisplayName() throws WebdavProtocolException {
        return attachment.getFilename();
    }

    @Override
    public String getETag() throws WebdavProtocolException {
        if (false == exists() || null == attachment || null == attachment.getCreationDate()) {
            return "";
        }
        return String.format("%d-%d-%d", Integer.valueOf(getFactory().getSession().getContextId()), Integer.valueOf(attachment.getId()), Long.valueOf(attachment.getCreationDate().getTime()));
    }

    @Override
    public Date getLastModified() throws WebdavProtocolException {
        return new Date(0);
    }

    @Override
    public Long getLength() throws WebdavProtocolException {
        return Long.valueOf(attachment.getFilesize());
    }

    @Override
    public String getContentType() throws WebdavProtocolException {
        return attachment.getFileMIMEType();
    }

    @Override
    public Date getCreationDate() throws WebdavProtocolException {
        return attachment.getCreationDate();
    }

    @Override
    public boolean hasBody() throws WebdavProtocolException {
        return true;
    }

    @Override
    public InputStream getBody() throws WebdavProtocolException {
        AttachmentBase attachments = Attachments.getInstance();
        try {
            return attachments.getAttachedFile(factory.getSession(), attachment.getFolderId(), attachment.getAttachedId(),
                attachment.getModuleId(), attachment.getId(), factory.getContext(), factory.getUser(), factory.getUserConfiguration());
        } catch (OXException e) {
            throw AttachmentUtils.protocolException(e, getUrl());
        }
    }

}
